@@ -85,6 +85,13 @@ usage['export'] = """kmcos export <xml-file> [<export-path>]
             lat_int is EXPERIMENTAL and not made
             for production, yet.
 
+        -t/--temp_acc
+            Use temporal acceleration scheme.
+            Builds the modules base_acc.f90, lattice_acc.mpy, 
+            proclist_constants_acc.mpy and 
+            proclist_generic_subroutines_acc.mpy.
+            Default is false.
+
         -d/--debug
             Turn on assertion statements in F90 code.
             (Only active in compile step)
@@ -207,6 +214,11 @@ def get_options(args=None, get_parser=False):
     parser.add_option('-c', '--catmap',
                       default=False,
                       action='store_true')
+   
+    parser.add_option('-t', '--temp_acc',
+                      default=False,
+                      dest='temp_acc',
+                      action='store_true')
     
     parser.add_option('--acf',
                       dest='acf',
@@ -282,17 +294,37 @@ def main(args=None):
         from time import time
         from kmcos.run import KMC_Model
         model = KMC_Model(print_rates=False, banner=False)
-        time0 = time()
-        try:
-            model.proclist.do_kmc_steps(nsteps)
-        except:  # kmcos < 0.3 had no model.proclist.do_kmc_steps
+        accelerated = model.can_accelerate
+        if not accelerated:
+            time0 = time()
+            try:
+                model.proclist.do_kmc_steps(nsteps)
+            except:  # kmos < 0.3 had no model.proclist.do_kmc_steps
+                model.do_steps(nsteps)
+
+            needed_time = time() - time0
+            print('Using the [%s] backend.' % model.get_backend())
+            print('%s steps took %.2f seconds' % (nsteps, needed_time))
+            print('Or %.2e steps/s' % (1e6 / needed_time))
+            model.deallocate()
+        else:
+            time0 = time()
             model.do_steps(nsteps)
+            needed_time = time() - time0
+            print('Using the [%s] backend.' % model.get_backend())
+            print('Using the temporal acceleration scheme')
+            print('%s normal steps took %.2f seconds' % (nsteps, needed_time))
+            print('Or %.2e steps/s' % (1e6 / needed_time))
+            print('')
+            model.deallocate()
+            model = KMC_Model(print_rates=False, banner=False)
+            time0 = time()
+            model.do_acc_steps(nsteps)
+            needed_time = time() - time0
+            print('%s accelerated steps took %.2f seconds' % (nsteps, needed_time))
+            print('Or %.2e steps/s' % (1e6 / needed_time))
+            model.deallocate()
 
-        needed_time = time() - time0
-        print('Using the [%s] backend.' % model.get_backend())
-        print('%s steps took %.2f seconds' % (nsteps, needed_time))
-        print('Or %.2e steps/s' % (1e6 / needed_time))
-        model.deallocate()
     elif args[0] == 'build':
         from kmcos.utils import build
         build(options)
@@ -340,8 +372,9 @@ def main(args=None):
         project.shorten_names(max_length=options.variable_length)
 
         kmcos.io.export_source(project,
-                              export_dir,
-                              options=options)
+                               export_dir,
+                               options=options,
+                               accelerated=options.temp_acc)
 
         if ((os.name == 'posix'
            and os.uname()[0] in ['Linux', 'Darwin'])
