@@ -549,14 +549,14 @@ class Project(object):
                 long_name = process.name
                 stub = process.name[:max_length - digits]
                 short_number = len(stub_map.get(stub, []))
-                short_name = '{stub}{short_number:04d}'
+                short_name = '{}{:04d}'.format(stub, short_number)
                 stub_map.setdefault(stub, []).append((short_name, long_name))
                 abbreviation_map[short_name] = long_name
                 fullform_map[long_name] = short_name
 
                 process.name = short_name
 
-        with open('abbreviations_{self.meta.model_name}.dat', 'w') as outfile:
+        with open('abbreviations_{}.dat'.format(self.meta.model_name), 'w') as outfile:
             outfile.write(pprint.pformat(stub_map))
 
     def save(self, filename=None, validate=True):
@@ -884,15 +884,21 @@ class Project(object):
                 return
             for child in root:
                 if child.tag == 'lattice':
+                    print("READING CELL SIZE")
+                    print(child.attrib['cell_size'])
                     cell = np.array([float(i)
                                      for i in
                                      child.attrib['cell_size'].split()])
+                    print("CELL")
+                    print(cell)
                     if len(cell) == 3:
                         self.layer_list.cell = np.diag(np.array(cell))
                     elif len(cell) == 9:
                         self.layer_list.cell = np.array(cell).reshape(3, 3)
                     else:
                         raise UserWarning('%s not understood' % cell)
+                    print("LAYER LIST CELL")
+                    print(self.layer_list.cell)
                     self.layer_list.default_layer = \
                         child.attrib['default_layer']
                     if 'substrate_layer' in child.attrib:
